obelisk.asynchronous.producer.Producer
======================================

.. currentmodule:: obelisk.asynchronous.producer

.. autoclass:: Producer
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Producer.__init__
      ~Producer.http_post
      ~Producer.send
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Producer.grace_period
      ~Producer.token
      ~Producer.token_expires
      ~Producer.retry_strategy
      ~Producer.kind
      ~Producer.log
   
   